@@ -116,6 +116,9 @@ class UserEvent(Document):
     repository = StringField(required=True)
     timestamp = DateTimeField(required=True)
 
+    # Processed File List
+    file_list = ListField()
+
     # Commit fields
     sha = StringField(required=True)
     ref = StringField(required=True, null=True)
@@ -171,9 +174,9 @@ class PrEvent(Document):
     repo_type = StringField()
     category = DictField()
     file_count = DictField()
-    tokens = ListField()
-    files = ListField()
-    omitted_files = ListField()
+    tokens = DictField()
+    file_list = ListField()
+    file_details = ListField()
 
     # Size and details
     total_length = IntField(default=0)
